[orca] Yet more updated regression tests.



commit c608c1c71dd3389d1d3994d8bba1fc29e18c11e6
Author: Joanmarie Diggs <joanmarie diggs gmail com>
Date:   Wed Dec 29 15:04:47 2010 -0500

    Yet more updated regression tests.

 test/harness/utils.py                              |    2 +-
 test/html/FirefoxProfile/prefs.js                  |    1 +
 test/keystrokes/firefox/bug_589455.py              |   38 +---
 test/keystrokes/firefox/dojo_spinner.py            |  169 +++-------------
 .../keystrokes/firefox/flat_review_text_by_line.py |   26 ++-
 .../firefox/flat_review_text_by_word_and_char.py   |   29 ++-
 test/keystrokes/firefox/html_role_combo_box.py     |   14 +-
 test/keystrokes/firefox/html_struct_nav_lists.py   |    2 -
 test/keystrokes/firefox/line_nav_wiki.py           |  219 ++++++++++----------
 .../firefox/mouseover_javascript_alert.py          |    2 +-
 test/keystrokes/firefox/mouseover_yahoo_menus.py   |    6 +-
 test/keystrokes/firefox/moz_menu.py                |   17 +-
 test/keystrokes/firefox/sayAll_enter_bug.py        |   11 +-
 test/keystrokes/firefox/uiuc_button.py             |   72 ++++---
 test/keystrokes/firefox/uiuc_grid.py               |    6 +-
 test/keystrokes/firefox/uiuc_radiobutton.py        |  100 ++++++----
 16 files changed, 310 insertions(+), 404 deletions(-)
---
diff --git a/test/harness/utils.py b/test/harness/utils.py
index f6bc4d3..131d08b 100644
--- a/test/harness/utils.py
+++ b/test/harness/utils.py
@@ -29,7 +29,7 @@ htmlURLPrefix = "file://" + htmlDir + "/"
 # These regex's attempt to provide a way to manage those differences.
 #
 firefoxAppNames = "(Firefox|Minefield|Namoroka)"
-firefoxFrameNames = "(Mozilla Firefox|Mozilla Firefox 4.0 Beta 7|Minefield|Namoroka)"
+firefoxFrameNames = "(Mozilla Firefox|Mozilla Firefox 4.0(| Beta [0-9](|pre))|Minefield|Namoroka)"
 firefoxLocationBarNames = "(Location|Search Bookmarks and History)"
 
 # Various OpenOffice names as a regex.  These are needed because OOo likes
diff --git a/test/html/FirefoxProfile/prefs.js b/test/html/FirefoxProfile/prefs.js
index 119ca10..d45b70d 100644
--- a/test/html/FirefoxProfile/prefs.js
+++ b/test/html/FirefoxProfile/prefs.js
@@ -31,6 +31,7 @@ user_pref("browser.tabs.warnOnOpen", false);
 user_pref("browser.warnOnQuit", false);
 user_pref("dom.disable_window_status_change", false);
 user_pref("extensions.lastAppVersion", "4.0b7");
+user_pref("extensions.testpilot.runStudies", false);
 user_pref("extensions.update.notifyUser", false);
 user_pref("extensions.update.enabled", false);
 user_pref("intl.charsetmenu.browser.cache", "UTF-8, ISO-8859-1");
diff --git a/test/keystrokes/firefox/bug_589455.py b/test/keystrokes/firefox/bug_589455.py
index 715b997..5167823 100644
--- a/test/keystrokes/firefox/bug_589455.py
+++ b/test/keystrokes/firefox/bug_589455.py
@@ -53,41 +53,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Return"))
 sequence.append(utils.AssertPresentationAction(
     "Press Return to active the link",
-    ["BUG? - With Firefox 4 it seems we don't say 'Loading. Please wait.' Perhaps we're missing an event?? Also, we're presenting the first line multiple times.",
-#    "BRAILLE LINE:  'Loading.  Please wait.'",
-#    "     VISIBLE:  'Loading.  Please wait.', cursor=0",
-     "BRAILLE LINE:  'Here are some of our local test files:'",
-     "     VISIBLE:  'Here are some of our local test ', cursor=1",
-     "BRAILLE LINE:  'Links to test files'",
-     "     VISIBLE:  'Links to test files', cursor=0",
-     "BRAILLE LINE:  'Here are some of our local test files:'",
-     "     VISIBLE:  'Here are some of our local test ', cursor=1",
-     "BRAILLE LINE:  'Finished loading Links to test files.'",
-     "     VISIBLE:  'Finished loading Links to test f', cursor=0",
-     "BRAILLE LINE:  'Here are some of our local test files:'",
-     "     VISIBLE:  'Here are some of our local test ', cursor=1",
-#    "SPEECH OUTPUT: 'Loading.  Please wait.'",
-     "SPEECH OUTPUT: 'Here are some of our local test files:'",
-     "SPEECH OUTPUT: 'Links to test files page'",
-     "SPEECH OUTPUT: 'Here are some of our local test files:'",
-     "SPEECH OUTPUT: 'Finished loading Links to test files.'",
-     "SPEECH OUTPUT: 'Here are some of our local test files:'",
-     "SPEECH OUTPUT: 'â?¢ anchors.html link'",
-     "SPEECH OUTPUT: 'â?¢ blockquotes.html link'",
-     "SPEECH OUTPUT: 'â?¢ bugzilla_top.html link'",
-     "SPEECH OUTPUT: 'â?¢ combobox.html link'",
-     "SPEECH OUTPUT: 'â?¢ fieldset.html link'",
-     "SPEECH OUTPUT: 'â?¢ htmlpage.html link'",
-     "SPEECH OUTPUT: 'â?¢ image-test.html link'",
-     "SPEECH OUTPUT: 'â?¢ linebreak-test.html link'",
-     "SPEECH OUTPUT: 'â?¢ lists.html link'",
-     "SPEECH OUTPUT: 'â?¢ samesizearea.html link'",
-     "SPEECH OUTPUT: 'â?¢ simpleform.html link'",
-     "SPEECH OUTPUT: 'â?¢ simpleheader.html link'",
-     "SPEECH OUTPUT: 'â?¢ slash-test.html link'",
-     "SPEECH OUTPUT: 'â?¢ status-bar.html link'",
-     "SPEECH OUTPUT: 'â?¢ tables.html link'",
-     "SPEECH OUTPUT: 'â?¢ textattributes.html link'"]))
+    ["BRAILLE LINE:  'Here are some of our local test files:'",
+     "     VISIBLE:  'Here are some of our local test ', cursor=0",
+     "SPEECH OUTPUT: 'Here are some of our local test files: â?¢anchors.htmlâ?¢blockquotes.htmlâ?¢bugzilla_top.htmlâ?¢combobox.htmlâ?¢fieldset.htmlâ?¢htmlpage.htmlâ?¢image-test.htmlâ?¢linebreak-test.htmlâ?¢lists.htmlâ?¢samesizearea.htmlâ?¢simpleform.htmlâ?¢simpleheader.htmlâ?¢slash-test.htmlâ?¢status-bar.htmlâ?¢tables.htmlâ?¢textattributes.html'"]))
 
 ########################################################################
 # Close the demo
diff --git a/test/keystrokes/firefox/dojo_spinner.py b/test/keystrokes/firefox/dojo_spinner.py
index 46ccc54..2dd8618 100644
--- a/test/keystrokes/firefox/dojo_spinner.py
+++ b/test/keystrokes/firefox/dojo_spinner.py
@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #!/usr/bin/python
 
 """Test of Dojo spinner presentation using Firefox.
@@ -17,11 +18,6 @@ sequence.append(WaitForWindowActivate(utils.firefoxFrameNames, None))
 ########################################################################
 # Load the dojo spinner demo.
 #
-# NOTE: After 5 Aug 2009, the test sets the required state to False by
-# Default. The state can be toggled by pressing a button, which is NOT
-# in the Tab order. :-( Therefore, for now, use the most recent archive
-# which has required set to True.
-#
 sequence.append(KeyComboAction("<Control>l"))
 sequence.append(WaitForFocus(acc_role=pyatspi.ROLE_ENTRY))
 sequence.append(TypeAction(utils.DojoNightlyURLPrefix + "form/test_Spinner.html"))
@@ -44,9 +40,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "Tab to the first spinner",
-    ["BRAILLE LINE:  'Spinbox #1: 900 $l required'",
-     "     VISIBLE:  'Spinbox #1: 900 $l required', cursor=16",
-     "SPEECH OUTPUT: 'Spinbox #1: 900 selected spin button required'"]))
+    ["BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "SPEECH OUTPUT: 'Spinbox #1: 900 selected spin button'"]))
 
 ########################################################################
 # Use down arrow to decrement spinner value.  
@@ -55,11 +51,12 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "first spinner decrement 1", 
-    ["BRAILLE LINE:  'Spinbox #1: 900 $l required'",
-     "     VISIBLE:  'Spinbox #1: 900 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 899 $l required'",
-     "     VISIBLE:  'Spinbox #1: 899 $l required', cursor=16",
-     "SPEECH OUTPUT: '899'"]))
+    ["BUG? - Why aren't we speaking or displaying the new value??",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "SPEECH OUTPUT: ''"]))
 
 ########################################################################
 # Use down arrow to decrement spinner value.  
@@ -68,50 +65,12 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "first spinner decrement 2", 
-    ["BRAILLE LINE:  'Spinbox #1: 899 $l required'",
-     "     VISIBLE:  'Spinbox #1: 899 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 898 $l required'",
-     "     VISIBLE:  'Spinbox #1: 898 $l required', cursor=16",
-     "SPEECH OUTPUT: '898'"]))
-
-########################################################################
-# Use down arrow to decrement spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner decrement 3", 
-    ["BRAILLE LINE:  'Spinbox #1: 898 $l required'",
-     "     VISIBLE:  'Spinbox #1: 898 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 897 $l required'",
-     "     VISIBLE:  'Spinbox #1: 897 $l required', cursor=16",
-     "SPEECH OUTPUT: '897'"]))
-
-########################################################################
-# Use down arrow to decrement spinner value. 
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner decrement 4", 
-    ["BRAILLE LINE:  'Spinbox #1: 897 $l required'",
-     "     VISIBLE:  'Spinbox #1: 897 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 896 $l required'",
-     "     VISIBLE:  'Spinbox #1: 896 $l required', cursor=16",
-     "SPEECH OUTPUT: '896'"]))
-
-########################################################################
-# Use down arrow to decrement spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner decrement 5", 
-    ["BRAILLE LINE:  'Spinbox #1: 896 $l required'",
-     "     VISIBLE:  'Spinbox #1: 896 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 895 $l required'",
-     "     VISIBLE:  'Spinbox #1: 895 $l required', cursor=16",
-     "SPEECH OUTPUT: '895'"]))
+    ["BUG? - Why aren't we speaking or displaying the new value??",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "SPEECH OUTPUT: ''"]))
 
 ########################################################################
 # Use up arrow to increment spinner value. 
@@ -120,89 +79,12 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "first spinner increment 1", 
-    ["BRAILLE LINE:  'Spinbox #1: 895 $l required'",
-     "     VISIBLE:  'Spinbox #1: 895 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 896 $l required'",
-     "     VISIBLE:  'Spinbox #1: 896 $l required', cursor=16",
-     "SPEECH OUTPUT: '896'"]))
-
-########################################################################
-# Use up arrow to increment spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner increment 2", 
-    ["BRAILLE LINE:  'Spinbox #1: 896 $l required'",
-     "     VISIBLE:  'Spinbox #1: 896 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 897 $l required'",
-     "     VISIBLE:  'Spinbox #1: 897 $l required', cursor=16",
-     "SPEECH OUTPUT: '897'"]))
-
-########################################################################
-# Use up arrow to increment spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner increment 3", 
-    ["BRAILLE LINE:  'Spinbox #1: 897 $l required'",
-     "     VISIBLE:  'Spinbox #1: 897 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 898 $l required'",
-     "     VISIBLE:  'Spinbox #1: 898 $l required', cursor=16",
-     "SPEECH OUTPUT: '898'"]))
-
-########################################################################
-# Use up arrow to increment spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner increment 4", 
-    ["BRAILLE LINE:  'Spinbox #1: 898 $l required'",
-     "     VISIBLE:  'Spinbox #1: 898 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 899 $l required'",
-     "     VISIBLE:  'Spinbox #1: 899 $l required', cursor=16",
-     "SPEECH OUTPUT: '899'"]))
-
-########################################################################
-# Use up arrow to increment spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner increment 5", 
-    ["BRAILLE LINE:  'Spinbox #1: 899 $l required'",
-     "     VISIBLE:  'Spinbox #1: 899 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 900 $l required'",
-     "     VISIBLE:  'Spinbox #1: 900 $l required', cursor=16",
-     "SPEECH OUTPUT: '900'"]))
-
-########################################################################
-# Use up arrow to increment spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner increment 6", 
-    ["BRAILLE LINE:  'Spinbox #1: 900 $l required'",
-     "     VISIBLE:  'Spinbox #1: 900 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 901 $l required'",
-     "     VISIBLE:  'Spinbox #1: 901 $l required', cursor=16",
-     "SPEECH OUTPUT: '901'"]))
-
-########################################################################
-# Use up arrow to increment spinner value.  
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "first spinner increment 7", 
-    ["BRAILLE LINE:  'Spinbox #1: 901 $l required'",
-     "     VISIBLE:  'Spinbox #1: 901 $l required', cursor=16",
-     "BRAILLE LINE:  'Spinbox #1: 902 $l required'",
-     "     VISIBLE:  'Spinbox #1: 902 $l required', cursor=16",
-     "SPEECH OUTPUT: '902'"]))
+    ["BUG? - Why aren't we speaking or displaying the new value??",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "SPEECH OUTPUT: ''"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  
@@ -212,9 +94,10 @@ sequence.append(KeyComboAction("KP_Enter"))
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "basic whereAmI", 
-    ["BRAILLE LINE:  'Spinbox #1: 902 $l required'",
-     "     VISIBLE:  'Spinbox #1: 902 $l required', cursor=16",
-     "SPEECH OUTPUT: 'Spinbox #1: spin button 902 required'"]))
+    ["BUG? - Why aren't we displaying the current value??",
+     "BRAILLE LINE:  'â?² â?¼ Spinbox #1:  $l not fired yet! $lSet value to 400 Button Set value to null Button Set required to false Button'",
+     "     VISIBLE:  'Spinbox #1:  $l not fired yet! $', cursor=13",
+     "SPEECH OUTPUT: 'Spinbox #1: spin button 899'"]))
 
 ########################################################################
 # Close the demo
diff --git a/test/keystrokes/firefox/flat_review_text_by_line.py b/test/keystrokes/firefox/flat_review_text_by_line.py
index ae913f4..1f2f2f2 100644
--- a/test/keystrokes/firefox/flat_review_text_by_line.py
+++ b/test/keystrokes/firefox/flat_review_text_by_line.py
@@ -35,10 +35,8 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_8", 1000))
 sequence.append(utils.AssertPresentationAction(
     "flat review current line", 
-    ["BRAILLE LINE:  'On weaponry:'",
-     "     VISIBLE:  'On weaponry:', cursor=1",
-     "BRAILLE LINE:  'On weaponry: $l'",
-     "     VISIBLE:  'On weaponry: $l', cursor=12",
+    ["BRAILLE LINE:  'On weaponry: $l'",
+     "     VISIBLE:  'On weaponry: $l', cursor=1",
      "SPEECH OUTPUT: 'On weaponry:'"]))
 
 ########################################################################
@@ -80,9 +78,10 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_9"))
 sequence.append(utils.AssertPresentationAction(
     "flat review next line", 
-    ["BRAILLE LINE:  'Pope, and nice red uniforms - Oh damn!  $l'",
+    ["BUG? - Why are we presenting the text twice?",
+     "BRAILLE LINE:  'Pope, and nice red uniforms - Oh damn! Pope, and nice red uniforms - Oh damn!  $l'",
      "     VISIBLE:  'Pope, and nice red uniforms - Oh', cursor=1",
-     "SPEECH OUTPUT: 'Pope, and nice red uniforms - Oh damn! '"]))
+     "SPEECH OUTPUT: 'Pope, and nice red uniforms - Oh damn! Pope, and nice red uniforms - Oh damn! '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_9"))
@@ -104,9 +103,10 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_9"))
 sequence.append(utils.AssertPresentationAction(
     "flat review next line", 
-    ["BRAILLE LINE:  'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance.  $l'",
+    ["BUG? - Why are we presenting the text twice?",
+     "BRAILLE LINE:  'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance.  $l'",
      "     VISIBLE:  'be free. Three last chances. You', cursor=1",
-     "SPEECH OUTPUT: 'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. '"]))
+     "SPEECH OUTPUT: 'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_9"))
@@ -139,9 +139,10 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_7"))
 sequence.append(utils.AssertPresentationAction(
     "flat review previous line", 
-    ["BRAILLE LINE:  'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance.  $l'",
+    ["BUG? - Why are we presenting the text twice?",
+     "BRAILLE LINE:  'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance.  $l'",
      "     VISIBLE:  'be free. Three last chances. You', cursor=1",
-     "SPEECH OUTPUT: 'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. '"]))
+     "SPEECH OUTPUT: 'be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. be free. Three last chances. You have three last chances, the nature of which I have divulged in my previous utterance. '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_7"))
@@ -163,9 +164,10 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_7"))
 sequence.append(utils.AssertPresentationAction(
     "flat review previous line", 
-    ["BRAILLE LINE:  'Pope, and nice red uniforms - Oh damn!  $l'",
+    ["BUG? - Why are we presenting the text twice?",
+     "BRAILLE LINE:  'Pope, and nice red uniforms - Oh damn! Pope, and nice red uniforms - Oh damn!  $l'",
      "     VISIBLE:  'Pope, and nice red uniforms - Oh', cursor=1",
-     "SPEECH OUTPUT: 'Pope, and nice red uniforms - Oh damn! '"]))
+     "SPEECH OUTPUT: 'Pope, and nice red uniforms - Oh damn! Pope, and nice red uniforms - Oh damn! '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_7"))
diff --git a/test/keystrokes/firefox/html_role_combo_box.py b/test/keystrokes/firefox/html_role_combo_box.py
index 6b95fe4..4ef1307 100644
--- a/test/keystrokes/firefox/html_role_combo_box.py
+++ b/test/keystrokes/firefox/html_role_combo_box.py
@@ -42,13 +42,13 @@ sequence.append(utils.AssertPresentationAction(
 ########################################################################
 # Press Tab once to get to the Severity link. 
 #
-#sequence.append(utils.StartRecordingAction())
-#sequence.append(KeyComboAction("Tab"))
-#sequence.append(utils.AssertPresentationAction(
-#    "Tab to Severity combo box", 
-#    ["BRAILLE LINE:  'Severity: Severity normal Combo'",
-#     "     VISIBLE:  'Severity: Severity normal Combo', cursor=1",
-#     "SPEECH OUTPUT: 'Severity link'"]))
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Tab"))
+sequence.append(utils.AssertPresentationAction(
+    "Tab to Severity combo box", 
+    ["BRAILLE LINE:  'Severity: Severity normal Combo'",
+     "     VISIBLE:  'Severity: Severity normal Combo', cursor=1",
+     "SPEECH OUTPUT: 'Severity link'"]))
 
 ########################################################################
 # Press Tab once to get to the Severity combo box.  This combo box
diff --git a/test/keystrokes/firefox/html_struct_nav_lists.py b/test/keystrokes/firefox/html_struct_nav_lists.py
index 3f48581..a851fb4 100644
--- a/test/keystrokes/firefox/html_struct_nav_lists.py
+++ b/test/keystrokes/firefox/html_struct_nav_lists.py
@@ -37,8 +37,6 @@ sequence.append(utils.AssertPresentationAction(
     "Top of file", 
     ["BRAILLE LINE:  'Welcome to a List of Lists h1'",
      "     VISIBLE:  'Welcome to a List of Lists h1', cursor=1",
-     "BRAILLE LINE:  'Welcome to a List of Lists h1'",
-     "     VISIBLE:  'Welcome to a List of Lists h1', cursor=1",
      "SPEECH OUTPUT: 'Welcome to a List of Lists heading level 1'"]))
 
 ########################################################################
diff --git a/test/keystrokes/firefox/line_nav_wiki.py b/test/keystrokes/firefox/line_nav_wiki.py
index 4a880ff..1b6e193 100644
--- a/test/keystrokes/firefox/line_nav_wiki.py
+++ b/test/keystrokes/firefox/line_nav_wiki.py
@@ -53,8 +53,8 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'live.gnome.org h1 Search $l Titles Button Text Button'",
-     "     VISIBLE:  'live.gnome.org h1 Search $l Titl', cursor=1",
+    ["BRAILLE LINE:  'live.gnome.org h1 Search $lTitles Button Text Button'",
+     "     VISIBLE:  'live.gnome.org h1 Search $lTitle', cursor=1",
      "SPEECH OUTPUT: 'live.gnome.org heading level 1 Search: text Search Titles button Text button'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -106,7 +106,7 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'Orca Logo Image', cursor=1",
      "BRAILLE LINE:  'Orca Logo Image'",
      "     VISIBLE:  'Orca Logo Image', cursor=1",
-     "SPEECH OUTPUT: 'Orca Logo link image'"
+     "SPEECH OUTPUT: 'Orca Logo link image'",
      "SPEECH OUTPUT: 'Orca Logo link image'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -129,64 +129,64 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '1. Welcome to Orca!'",
-     "     VISIBLE:  '1. Welcome to Orca!', cursor=1",
+    ["BRAILLE LINE:  '1.Welcome to Orca!'",
+     "     VISIBLE:  '1.Welcome to Orca!', cursor=1",
      "SPEECH OUTPUT: '1. Welcome to Orca! link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '2. About'",
-     "     VISIBLE:  '2. About', cursor=1",
+    ["BRAILLE LINE:  '2.About'",
+     "     VISIBLE:  '2.About', cursor=1",
      "SPEECH OUTPUT: '2. About link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '3. Audio Guides'",
-     "     VISIBLE:  '3. Audio Guides', cursor=1",
+    ["BRAILLE LINE:  '3.Audio Guides'",
+     "     VISIBLE:  '3.Audio Guides', cursor=1",
      "SPEECH OUTPUT: '3. Audio Guides link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '4. Download/Installation'",
-     "     VISIBLE:  '4. Download/Installation', cursor=1",
+    ["BRAILLE LINE:  '4.Download/Installation'",
+     "     VISIBLE:  '4.Download/Installation', cursor=1",
      "SPEECH OUTPUT: '4. Download/Installation link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '5. Configuration/Use'",
-     "     VISIBLE:  '5. Configuration/Use', cursor=1",
+    ["BRAILLE LINE:  '5.Configuration/Use'",
+     "     VISIBLE:  '5.Configuration/Use', cursor=1",
      "SPEECH OUTPUT: '5. Configuration/Use link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '6. Accessible Applications'",
-     "     VISIBLE:  '6. Accessible Applications', cursor=1",
+    ["BRAILLE LINE:  '6.Accessible Applications'",
+     "     VISIBLE:  '6.Accessible Applications', cursor=1",
      "SPEECH OUTPUT: '6. Accessible Applications link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '7. How Can I Help?'",
-     "     VISIBLE:  '7. How Can I Help?', cursor=1",
+    ["BRAILLE LINE:  '7.How Can I Help?'",
+     "     VISIBLE:  '7.How Can I Help?', cursor=1",
      "SPEECH OUTPUT: '7. How Can I Help? link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '8. More Information'",
-     "     VISIBLE:  '8. More Information', cursor=1",
+    ["BRAILLE LINE:  '8.More Information'",
+     "     VISIBLE:  '8.More Information', cursor=1",
      "SPEECH OUTPUT: '8. More Information link'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -210,7 +210,7 @@ sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
     ["BRAILLE LINE:  'assistive technology for people with visual impairments. Using'",
-     "     VISIBLE:  'assistive technology for people', cursor=1",
+     "     VISIBLE:  'assistive technology for people ', cursor=1",
      "SPEECH OUTPUT: 'assistive technology for people with visual impairments. Using'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -337,24 +337,24 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'â?¢ Walk through of the installation of Ubuntu 7.4. Very helpful tutorial'",
-     "     VISIBLE:  'â?¢ Walk through of the installati', cursor=1",
+    ["BRAILLE LINE:  'â?¢Walk through of the installation of Ubuntu 7.4. Very helpful tutorial'",
+     "     VISIBLE:  'â?¢Walk through of the installatio', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Walk through of the installation of Ubuntu 7.4. Very helpful tutorial link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'â?¢ Review of Fedora 7 and the Orca screen reader for the Gnome graphical desktop'",
-     "     VISIBLE:  'â?¢ Review of Fedora 7 and the Orc', cursor=1",
+    ["BRAILLE LINE:  'â?¢Review of Fedora 7 and the Orca screen reader for the Gnome graphical desktop'",
+     "     VISIBLE:  'â?¢Review of Fedora 7 and the Orca', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Review of Fedora 7 and the Orca screen reader for the Gnome graphical desktop link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'â?¢ Guide to installing the latest versions of Firefox and Orca'",
-     "     VISIBLE:  'â?¢ Guide to installing the latest', cursor=1",
+    ["BRAILLE LINE:  'â?¢Guide to installing the latest versions of Firefox and Orca'",
+     "     VISIBLE:  'â?¢Guide to installing the latest ', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Guide to installing the latest versions of Firefox and Orca link'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -641,24 +641,24 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'â?¢ Dive Into Python, Mark Pilgrim'",
-     "     VISIBLE:  'â?¢ Dive Into Python, Mark Pilgrim', cursor=1",
+    ["BRAILLE LINE:  'â?¢Dive Into Python, Mark Pilgrim'",
+     "     VISIBLE:  'â?¢Dive Into Python, Mark Pilgrim', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Dive Into Python, Mark Pilgrim link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'â?¢ Python in a Nutshell, Alex Martelli'",
-     "     VISIBLE:  'â?¢ Python in a Nutshell, Alex Mar', cursor=1",
+    ["BRAILLE LINE:  'â?¢Python in a Nutshell, Alex Martelli'",
+     "     VISIBLE:  'â?¢Python in a Nutshell, Alex Mart', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Python in a Nutshell, Alex Martelli link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'â?¢ Python Pocket Reference, Mark Lutz'",
-     "     VISIBLE:  'â?¢ Python Pocket Reference, Mark ', cursor=1",
+    ["BRAILLE LINE:  'â?¢Python Pocket Reference, Mark Lutz'",
+     "     VISIBLE:  'â?¢Python Pocket Reference, Mark L', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Python Pocket Reference, Mark Lutz link'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -769,10 +769,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BUG? - In 3.1 we aren't presenting More Actions at times; other times we are",
-     "BRAILLE LINE:  'Combo'",
-     "     VISIBLE:  'Combo', cursor=1",
-     "SPEECH OUTPUT: 'combo box'"]))
+    ["BRAILLE LINE:  'More Actions: Combo'",
+     "     VISIBLE:  'More Actions: Combo', cursor=1",
+     "SPEECH OUTPUT: 'More Actions: combo box'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
@@ -789,10 +788,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BUG? - In 3.1 we aren't presenting More Actions at times; other times we are",
-     "BRAILLE LINE:  'Combo'",
-     "     VISIBLE:  'Combo', cursor=1",
-     "SPEECH OUTPUT: 'combo box'"]))
+    ["BRAILLE LINE:  'More Actions: Combo'",
+     "     VISIBLE:  'More Actions: Combo', cursor=1",
+     "SPEECH OUTPUT: 'More Actions: combo box'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -902,24 +900,24 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  'â?¢ Python Pocket Reference, Mark Lutz'",
-     "     VISIBLE:  'â?¢ Python Pocket Reference, Mark ', cursor=1",
+    ["BRAILLE LINE:  'â?¢Python Pocket Reference, Mark Lutz'",
+     "     VISIBLE:  'â?¢Python Pocket Reference, Mark L', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Python Pocket Reference, Mark Lutz link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  'â?¢ Python in a Nutshell, Alex Martelli'",
-     "     VISIBLE:  'â?¢ Python in a Nutshell, Alex Mar', cursor=1",
+    ["BRAILLE LINE:  'â?¢Python in a Nutshell, Alex Martelli'",
+     "     VISIBLE:  'â?¢Python in a Nutshell, Alex Mart', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Python in a Nutshell, Alex Martelli link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  'â?¢ Dive Into Python, Mark Pilgrim'",
-     "     VISIBLE:  'â?¢ Dive Into Python, Mark Pilgrim', cursor=1",
+    ["BRAILLE LINE:  'â?¢Dive Into Python, Mark Pilgrim'",
+     "     VISIBLE:  'â?¢Dive Into Python, Mark Pilgrim', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Dive Into Python, Mark Pilgrim link'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -1126,17 +1124,17 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'navigation mechanisms are consistent across most desktop applications.'",
-     "     VISIBLE:  'navigation mechanisms are consis', cursor=1",
-     "SPEECH OUTPUT: 'navigation mechanisms are consistent across most desktop applications.'"]))
+    ["BRAILLE LINE:  'These navigation mechanisms are consistent across most desktop applications.'",
+     "     VISIBLE:  'These navigation mechanisms are ', cursor=1",
+     "SPEECH OUTPUT: 'These navigation mechanisms are consistent across most desktop applications.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'information as you navigate the desktop using the built-in navigation mechanisms of GNOME. These'",
+    ["BRAILLE LINE:  'information as you navigate the desktop using the built-in navigation mechanisms of GNOME.'",
      "     VISIBLE:  'information as you navigate the ', cursor=1",
-     "SPEECH OUTPUT: 'information as you navigate the desktop using the built-in navigation mechanisms of GNOME link . These'"]))
+     "SPEECH OUTPUT: 'information as you navigate the desktop using the built-in navigation mechanisms of GNOME link .'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -1206,24 +1204,24 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'â?¢ Guide to installing the latest versions of Firefox and Orca'",
-     "     VISIBLE:  'â?¢ Guide to installing the latest', cursor=1",
+    ["BRAILLE LINE:  'â?¢Guide to installing the latest versions of Firefox and Orca'",
+     "     VISIBLE:  'â?¢Guide to installing the latest ', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Guide to installing the latest versions of Firefox and Orca link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'â?¢ Review of Fedora 7 and the Orca screen reader for the Gnome graphical desktop'",
-     "     VISIBLE:  'â?¢ Review of Fedora 7 and the Orc', cursor=1",
+    ["BRAILLE LINE:  'â?¢Review of Fedora 7 and the Orca screen reader for the Gnome graphical desktop'",
+     "     VISIBLE:  'â?¢Review of Fedora 7 and the Orca', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Review of Fedora 7 and the Orca screen reader for the Gnome graphical desktop link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'â?¢ Walk through of the installation of Ubuntu 7.4. Very helpful tutorial'",
-     "     VISIBLE:  'â?¢ Walk through of the installati', cursor=1",
+    ["BRAILLE LINE:  'â?¢Walk through of the installation of Ubuntu 7.4. Very helpful tutorial'",
+     "     VISIBLE:  'â?¢Walk through of the installatio', cursor=1",
      "SPEECH OUTPUT: 'â?¢ Walk through of the installation of Ubuntu 7.4. Very helpful tutorial link'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -1278,19 +1276,17 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-     []))
-#    ["BRAILLE LINE:  '" + bugzillaStringBraille + "( |)" + "how we use Bugzilla\).'",
-#     "     VISIBLE:  '" + bugzillaStringVisible + "', cursor=1",
-#     "SPEECH OUTPUT: '" + bugzillaStringSpeech + "( |)" + "how we use Bugzilla link \).'"]))
+    ["BRAILLE LINE:  'how we use Bugzilla\).'",
+     "     VISIBLE:  'how we use Bugzilla\).', cursor=1",
+     "SPEECH OUTPUT: 'how we use Bugzilla link \).'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-     []))
-#    ["BRAILLE LINE:  'along with known problems in other components, is maintained in" + "( |)" + bugzillaStringBraille + "'",
-#     "     VISIBLE:  'along with known problems in oth', cursor=1",
-#     "SPEECH OUTPUT: 'along with known problems in other components, is maintained in" + "( |)" + bugzillaStringSpeech + "( link|)'"]))
+    ["BRAILLE LINE:  'along with known problems in other components, is maintained in Bugzilla \(please see our notes on'",
+     "     VISIBLE:  'along with known problems in oth', cursor=1",
+     "SPEECH OUTPUT: 'along with known problems in other components, is maintained in Bugzilla link  (please see our notes on link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -1304,57 +1300,66 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'with contributions from many community members.'",
-     "     VISIBLE:  'with contributions from many com', cursor=1",
-     "SPEECH OUTPUT: 'with contributions from many community members link .'"]))
+    ["BRAILLE LINE:  'community members.'",
+     "     VISIBLE:  'community members.', cursor=1",
+     "SPEECH OUTPUT: 'community members link .'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'been led by the Accessibility Program Office of Sun Microsystems, Inc.'",
-     "     VISIBLE:  'been led by the Accessibility Pr', cursor=1",
-     "SPEECH OUTPUT: 'been led by the Accessibility Program Office of Sun Microsystems, Inc. link'"]))
+    ["BUG? - Did we lose the word 'with'?",
+     "BRAILLE LINE:  'contributions from many'",
+     "     VISIBLE:  'contributions from many', cursor=1",
+     "SPEECH OUTPUT: 'contributions from many link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'AT-SPI (e.g., the GNOME desktop). The development of Orca has'",
-     "     VISIBLE:  'AT-SPI (e.g., the GNOME desktop)', cursor=1",
-     "SPEECH OUTPUT: 'AT-SPI (e.g., the GNOME desktop). The development of Orca has'"]))
+    ["BRAILLE LINE:  'development of Orca has been led by the Accessibility Program'",
+     "     VISIBLE:  'development of Orca has been led', cursor=1",
+     "SPEECH OUTPUT: 'development of Orca has been led by the Accessibility Program link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'helps provide access to applications and toolkits that support the'",
-     "     VISIBLE:  'helps provide access to applicat', cursor=1",
-     "SPEECH OUTPUT: 'helps provide access to applications and toolkits that support the'"]))
+    ["BRAILLE LINE:  'toolkits that support the AT-SPI (e.g., the GNOME desktop). The'",
+     "     VISIBLE:  'toolkits that support the AT-SPI', cursor=1",
+     "SPEECH OUTPUT: 'toolkits that support the AT-SPI (e.g., the GNOME desktop). The'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'combinations of speech synthesis, braille, and magnification, Orca'",
-     "     VISIBLE:  'combinations of speech synthesis', cursor=1",
-     "SPEECH OUTPUT: 'combinations of speech synthesis, braille, and magnification, Orca'"]))
+    ["BRAILLE LINE:  'magnification, Orca helps provide access to applications and'",
+     "     VISIBLE:  'magnification, Orca helps provid', cursor=1",
+     "SPEECH OUTPUT: 'magnification, Orca helps provide access to applications and'"]))
+
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Up"))
+sequence.append(utils.AssertPresentationAction(
+    "Line Up", 
+    ["BRAILLE LINE:  'various combinations of speech synthesis, braille, and'",
+     "     VISIBLE:  'various combinations of speech s', cursor=1",
+     "SPEECH OUTPUT: 'various combinations of speech synthesis, braille, and'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'technology for people with visual impairments. Using various'",
-     "     VISIBLE:  'technology for people with visua', cursor=1",
-     "SPEECH OUTPUT: 'technology for people with visual impairments. Using various'"]))
+    ["BRAILLE LINE:  'assistive technology for people with visual impairments. Using'",
+     "     VISIBLE:  'assistive technology for people ', cursor=1",
+     "SPEECH OUTPUT: 'assistive technology for people with visual impairments. Using'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'Orca is a free, open source, flexible, extensible, and powerful assistive'",
+    ["BRAILLE LINE:  'Orca is a free, open source, flexible, extensible, and powerful'",
      "     VISIBLE:  'Orca is a free, open source, fle', cursor=1",
-     "SPEECH OUTPUT: 'Orca is a free, open source, flexible, extensible, and powerful assistive'"]))
+     "SPEECH OUTPUT: 'Orca is a free, open source, flexible, extensible, and powerful'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -1368,64 +1373,64 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '8. More Information'",
-     "     VISIBLE:  '8. More Information', cursor=1",
+    ["BRAILLE LINE:  '8.More Information'",
+     "     VISIBLE:  '8.More Information', cursor=1",
      "SPEECH OUTPUT: '8. More Information link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '7. How Can I Help?'",
-     "     VISIBLE:  '7. How Can I Help?', cursor=1",
+    ["BRAILLE LINE:  '7.How Can I Help?'",
+     "     VISIBLE:  '7.How Can I Help?', cursor=1",
      "SPEECH OUTPUT: '7. How Can I Help? link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '6. Accessible Applications'",
-     "     VISIBLE:  '6. Accessible Applications', cursor=1",
+    ["BRAILLE LINE:  '6.Accessible Applications'",
+     "     VISIBLE:  '6.Accessible Applications', cursor=1",
      "SPEECH OUTPUT: '6. Accessible Applications link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '5. Configuration/Use'",
-     "     VISIBLE:  '5. Configuration/Use', cursor=1",
+    ["BRAILLE LINE:  '5.Configuration/Use'",
+     "     VISIBLE:  '5.Configuration/Use', cursor=1",
      "SPEECH OUTPUT: '5. Configuration/Use link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '4. Download/Installation'",
-     "     VISIBLE:  '4. Download/Installation', cursor=1",
+    ["BRAILLE LINE:  '4.Download/Installation'",
+     "     VISIBLE:  '4.Download/Installation', cursor=1",
      "SPEECH OUTPUT: '4. Download/Installation link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '3. Audio Guides'",
-     "     VISIBLE:  '3. Audio Guides', cursor=1",
+    ["BRAILLE LINE:  '3.Audio Guides'",
+     "     VISIBLE:  '3.Audio Guides', cursor=1",
      "SPEECH OUTPUT: '3. Audio Guides link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '2. About'",
-     "     VISIBLE:  '2. About', cursor=1",
+    ["BRAILLE LINE:  '2.About'",
+     "     VISIBLE:  '2.About', cursor=1",
      "SPEECH OUTPUT: '2. About link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '1. Welcome to Orca!'",
-     "     VISIBLE:  '1. Welcome to Orca!', cursor=1",
+    ["BRAILLE LINE:  '1.Welcome to Orca!'",
+     "     VISIBLE:  '1.Welcome to Orca!', cursor=1",
      "SPEECH OUTPUT: '1. Welcome to Orca! link'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -1450,6 +1455,9 @@ sequence.append(utils.AssertPresentationAction(
     "Line Up", 
     ["BRAILLE LINE:  'Orca Logo Image'",
      "     VISIBLE:  'Orca Logo Image', cursor=1",
+     "BRAILLE LINE:  'Orca Logo Image'",
+     "     VISIBLE:  'Orca Logo Image', cursor=1",
+     "SPEECH OUTPUT: 'Orca Logo link image'",
      "SPEECH OUTPUT: 'Orca Logo link image'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -1464,9 +1472,10 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'FAQ | DocIndex'",
-     "     VISIBLE:  'FAQ | DocIndex', cursor=1",
-     "SPEECH OUTPUT: 'FAQ link | DocIndex link'"]))
+    ["BUG? - Looks like we're getting the pipe twice.",
+     "BRAILLE LINE:  '| FAQ | DocIndex'",
+     "     VISIBLE:  '| FAQ | DocIndex', cursor=1",
+     "SPEECH OUTPUT: '| FAQ link  | DocIndex link'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -1498,7 +1507,7 @@ sequence.append(utils.AssertPresentationAction(
     "Line Up",
     ["BRAILLE LINE:  'live.gnome.org h1 Search $l Titles Button Text Button'",
      "     VISIBLE:  'live.gnome.org h1 Search $l Titl', cursor=1",
-     "SPEECH OUTPUT: 'live.gnome.org heading level 1 Search: text Search Titles button grayed Text button grayed'"]))
+     "SPEECH OUTPUT: 'live.gnome.org heading level 1 Search: text Search Titles button Text button'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
diff --git a/test/keystrokes/firefox/mouseover_javascript_alert.py b/test/keystrokes/firefox/mouseover_javascript_alert.py
index ccf6c83..48259e9 100644
--- a/test/keystrokes/firefox/mouseover_javascript_alert.py
+++ b/test/keystrokes/firefox/mouseover_javascript_alert.py
@@ -71,7 +71,7 @@ sequence.append(KeyComboAction("Escape"))
 sequence.append(utils.AssertPresentationAction(
     "Escape to dismiss the dialog.",
     ["BRAILLE LINE:  '" + utils.firefoxAppNames + " Application MouseOvers - " + utils.firefoxFrameNames + " Frame'",
-     "     VISIBLE:  'MouseOvers - " + utils.firefoxFrameNames + " Fra', cursor=1",
+     "     VISIBLE:  'MouseOvers - " + utils.firefoxFrameNames + "(| Fra| Frame)', cursor=1",
      "BRAILLE LINE:  'Orca Logo Image'",
      "     VISIBLE:  'Orca Logo Image', cursor=1",
      "SPEECH OUTPUT: 'MouseOvers - " + utils.firefoxFrameNames + " frame'",
diff --git a/test/keystrokes/firefox/mouseover_yahoo_menus.py b/test/keystrokes/firefox/mouseover_yahoo_menus.py
index 70aceee..c335e4f 100644
--- a/test/keystrokes/firefox/mouseover_yahoo_menus.py
+++ b/test/keystrokes/firefox/mouseover_yahoo_menus.py
@@ -47,7 +47,9 @@ sequence.append(KeyComboAction("KP_Divide"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
 sequence.append(utils.AssertPresentationAction(
     "Route the pointer to Communications",
-    ["BUG? - This should also be brailled.",
+    ["BUG? - This should also be brailled. Also, while accurate, we're too chatty here.",
+     "SPEECH OUTPUT: 'New item has been added PIM link'",
+     "SPEECH OUTPUT: 'New item has been added section'",
      "SPEECH OUTPUT: 'New item has been added section'"]))
 
 ########################################################################
@@ -77,7 +79,7 @@ sequence.append(utils.AssertPresentationAction(
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
-    "1. Tab to menu item",
+    "2. Tab to menu item",
     ["BRAILLE LINE:  'Avatars'",
      "     VISIBLE:  'Avatars', cursor=1",
      "SPEECH OUTPUT: 'Avatars link'"]))
diff --git a/test/keystrokes/firefox/moz_menu.py b/test/keystrokes/firefox/moz_menu.py
index d710d1e..0d29a23 100644
--- a/test/keystrokes/firefox/moz_menu.py
+++ b/test/keystrokes/firefox/moz_menu.py
@@ -77,10 +77,10 @@ sequence.append(PauseAction(2000))
 sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
     "Move to basic grey", 
-    ["BRAILLE LINE:  'Themes          >'",
-     "     VISIBLE:  'Themes          >', cursor=(0|1)",
-     "BRAILLE LINE:  'Themes          > Basic Grey'",
-     "     VISIBLE:  'Themes          > Basic Grey', cursor=19",
+    ["BRAILLE LINE:  'Basic Grey'",
+     "     VISIBLE:  'Basic Grey', cursor=(0|1)",
+     "BRAILLE LINE:  'Basic Grey'",
+     "     VISIBLE:  'Basic Grey', cursor=1",
      "SPEECH OUTPUT: 'menu'",
      "SPEECH OUTPUT: 'Basic Grey'"]))
 
@@ -153,11 +153,10 @@ sequence.append(KeyComboAction("Right"))
 sequence.append(PauseAction(1000))
 sequence.append(utils.AssertPresentationAction(
     "Move to one", 
-    ["KNOWN ISSUE - Depending on timing, we sometimes just display one rather than More",
-     "BRAILLE LINE:  'More                >'",
-     "     VISIBLE:  'More                >', cursor=(0|1)",
-     "BRAILLE LINE:  'More                > one'",
-     "     VISIBLE:  'More                > one', cursor=23",
+    ["BRAILLE LINE:  '(one|More                >)'",
+     "     VISIBLE:  '(one|More                >)', cursor=(0|1)",
+     "BRAILLE LINE:  '(one|More                > one)'",
+     "     VISIBLE:  '(one|More                > one)', cursor=(0|1|23)",
      "SPEECH OUTPUT: 'menu'",
      "SPEECH OUTPUT: 'one'"]))
 
diff --git a/test/keystrokes/firefox/sayAll_enter_bug.py b/test/keystrokes/firefox/sayAll_enter_bug.py
index c266d2d..ff6d58d 100644
--- a/test/keystrokes/firefox/sayAll_enter_bug.py
+++ b/test/keystrokes/firefox/sayAll_enter_bug.py
@@ -36,9 +36,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Control>Home"))
 sequence.append(utils.AssertPresentationAction(
     "Top of file",
-    ["BRAILLE LINE:  'Home Image Bugzilla'",
-     "     VISIBLE:  'Home Image Bugzilla', cursor=1",
-     "SPEECH OUTPUT: 'Home link image Bugzilla'"]))
+    ["BRAILLE LINE:  'Home Image Bugzilla New bug · Browse · Search · Reports · Account · Admin · Help Logged In joanmarie diggs gmail com | Log Out'",
+     "     VISIBLE:  'Home Image Bugzilla New bug · Br', cursor=1",
+     "SPEECH OUTPUT: 'Home link image Bugzilla New bug link  · Browse link  · Search link  · Reports link  · Account link  · Admin link  · Help link Logged In joanmarie diggs gmail com | Log Out link'"]))
 
 ########################################################################
 # SayAll to the End.
@@ -77,8 +77,7 @@ sequence.append(utils.AssertPresentationAction(
      "SPEECH OUTPUT: 'text'",
      "SPEECH OUTPUT: 'Description:'",
      "SPEECH OUTPUT: 'text'",
-     "SPEECH OUTPUT: ' ",
-     "'",
+     "SPEECH OUTPUT: 'blank'",
      "SPEECH OUTPUT: ' '",
      "SPEECH OUTPUT: 'Optional Fields'",
      "SPEECH OUTPUT: 'Cc:'",
@@ -90,7 +89,7 @@ sequence.append(utils.AssertPresentationAction(
      "SPEECH OUTPUT: 'text'",
      "SPEECH OUTPUT: 'Blocks:'",
      "SPEECH OUTPUT: 'text'",
-     "SPEECH OUTPUT: 'Commit button'",
+     "SPEECH OUTPUT: '   Commit button'",
      "SPEECH OUTPUT: '      Remember values as bookmarkable template button'",
      "SPEECH OUTPUT: '",
      "We've made a guess at your operating system. Please check it and, if we got it wrong, email bugmaster gnome org '",
diff --git a/test/keystrokes/firefox/uiuc_button.py b/test/keystrokes/firefox/uiuc_button.py
index 92529f9..f769c92 100644
--- a/test/keystrokes/firefox/uiuc_button.py
+++ b/test/keystrokes/firefox/uiuc_button.py
@@ -19,7 +19,7 @@ sequence.append(WaitForWindowActivate(utils.firefoxFrameNames, None))
 #
 sequence.append(KeyComboAction("<Control>l"))
 sequence.append(WaitForFocus(acc_role=pyatspi.ROLE_ENTRY))
-sequence.append(TypeAction("http://test.cita.uiuc.edu/aria/button/view_class.php?title=Button%20Example%201&ginc=includes/button1_class.inc&gcss=css/button1_class.css&gjs=../js/globals.js,../js/widgets_class.js,js/button1_class.js";))
+sequence.append(TypeAction("http://test.cita.illinois.edu/aria/button/button1.php";))
 sequence.append(KeyComboAction("Return"))
 sequence.append(WaitForDocLoad())
 sequence.append(WaitForFocus("class: Button Example 1", acc_role=pyatspi.ROLE_DOCUMENT_FRAME))
@@ -29,13 +29,17 @@ sequence.append(PauseAction(6000))
 ########################################################################
 # Tab to the first button.  The following will be presented.
 #
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
+
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to first button", 
-    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button &=y Italic i ToggleButton Bold B Button'",
-     "     VISIBLE:  'Font Larger + Button Font Smalle', cursor=1",
-     "SPEECH OUTPUT: 'Text Formating Controls 1 list Font Larger + button'"]))
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton &=y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Font Larger + ToggleButton &', cursor=1",
+     "SPEECH OUTPUT: 'Text Formating Controls 1 list Font Larger + toggle button not pressed'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  The following should be
@@ -46,19 +50,9 @@ sequence.append(KeyComboAction("KP_Enter"))
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "basic whereamI", 
-    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button &=y Italic i ToggleButton Bold B Button'",
-     "     VISIBLE:  'Font Larger + Button Font Smalle', cursor=1",
-     "SPEECH OUTPUT: 'Font Larger + button'"]))
-
-########################################################################
-# Now push the first button.  The following will be presented.
-#
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(TypeAction(" "))
-sequence.append(utils.AssertPresentationAction(
-    "push first button", 
-    [""]))
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton &=y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Font Larger + ToggleButton &', cursor=1",
+     "SPEECH OUTPUT: 'Font Larger + toggle button not pressed'"]))
 
 ########################################################################
 # Tab to the second button.
@@ -67,9 +61,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to second button", 
-    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button &=y Italic i ToggleButton Bold B Button'",
-     "     VISIBLE:  'Font Smaller - Button &=y Italic', cursor=1",
-     "SPEECH OUTPUT: 'Font Smaller - button'"]))
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton &=y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Font Smaller - ToggleButton ', cursor=1",
+     "SPEECH OUTPUT: 'Font Smaller - toggle button not pressed'"]))
 
 ########################################################################
 # Now push the second button.  The following will be presented.
@@ -78,7 +72,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(TypeAction(" "))
 sequence.append(utils.AssertPresentationAction(
     "push second button", 
-    [""]))
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton &=y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Font Smaller - ToggleButton ', cursor=1",
+     "SPEECH OUTPUT: 'not pressed'"]))
 
 ########################################################################
 # Tab to the third button.
@@ -87,8 +83,8 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to third button", 
-    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button &=y Italic i ToggleButton Bold B Button'",
-     "     VISIBLE:  '&=y Italic i ToggleButton Bold B', cursor=1",
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton &=y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '&=y Italic i ToggleButton & y Bo', cursor=1",
      "SPEECH OUTPUT: 'Italic i toggle button pressed'"]))
 
 ########################################################################
@@ -98,38 +94,50 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(TypeAction(" "))
 sequence.append(utils.AssertPresentationAction(
     "push third button", 
-    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
-     "     VISIBLE:  '& y Italic i ToggleButton Bold B', cursor=1",
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Italic i ToggleButton & y Bo', cursor=1",
      "SPEECH OUTPUT: 'not pressed'"]))
 
 ########################################################################
 # Tab to the fourth button.  The following will be presented.
 #
+sequence.append(PauseAction(3000))
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to fourth button", 
-    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
-     "     VISIBLE:  'Bold B Button', cursor=1",
-     "SPEECH OUTPUT: 'Bold B button'"]))
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Bold B ToggleButton', cursor=1",
+     "SPEECH OUTPUT: 'Bold B toggle button not pressed'"]))
 
 ########################################################################
 # Now push the fourth button.  The following will be presented.
 #
 sequence.append(utils.StartRecordingAction())
-sequence.append(TypeAction           ("  "))
+sequence.append(TypeAction("  "))
 sequence.append(utils.AssertPresentationAction(
     "push fourth button", 
-    [""]))
+    ["BUG? - Toggling doesn't appear to be working right here or on the next attempt.",
+     "BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton &=y Bold B ToggleButton'",
+     "     VISIBLE:  '&=y Bold B ToggleButton', cursor=1",
+     "BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Bold B ToggleButton', cursor=1",
+     "SPEECH OUTPUT: 'pressed'",
+     "SPEECH OUTPUT: 'not pressed'"]))
 
 ########################################################################
 # Now push the fourth button again.  The following will be presented.
 #
 sequence.append(utils.StartRecordingAction())
-sequence.append(TypeAction           ("  "))
+sequence.append(TypeAction("  "))
 sequence.append(utils.AssertPresentationAction(
     "push fourth button again", 
-    [""]))
+    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton &=y Bold B ToggleButton'",
+     "     VISIBLE:  '&=y Bold B ToggleButton', cursor=1",
+     "BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
+     "     VISIBLE:  '& y Bold B ToggleButton', cursor=1",
+     "SPEECH OUTPUT: 'pressed'",
+     "SPEECH OUTPUT: 'not pressed'"]))
 
 ########################################################################
 # Close the demo
diff --git a/test/keystrokes/firefox/uiuc_grid.py b/test/keystrokes/firefox/uiuc_grid.py
index 8e1841c..0ae906f 100644
--- a/test/keystrokes/firefox/uiuc_grid.py
+++ b/test/keystrokes/firefox/uiuc_grid.py
@@ -19,7 +19,7 @@ sequence.append(WaitForWindowActivate(utils.firefoxFrameNames, None))
 #
 sequence.append(KeyComboAction("<Control>l"))
 sequence.append(WaitForFocus(acc_role=pyatspi.ROLE_ENTRY))
-sequence.append(TypeAction("http://test.cita.uiuc.edu/aria/grid/view_inline.php?title=Grid%20Example%201:%20E-mail%20List%20with%20Row%20and%20Column%20Navigation&ginc=includes/grid1_inline.inc&gcss=css/grid1.css&gjs=../js/globals.js,../js/widgets_inline.js,js/grid1.js";))
+sequence.append(TypeAction("http://test.cita.illinois.edu/aria/grid/grid2.php";))
 sequence.append(KeyComboAction("Return"))
 sequence.append(WaitForDocLoad())
 
@@ -28,6 +28,10 @@ sequence.append(PauseAction(5000))
 ########################################################################
 # Tab to grid
 #
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
+
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(PauseAction(2000))
diff --git a/test/keystrokes/firefox/flat_review_text_by_word_and_char.py b/test/keystrokes/firefox/flat_review_text_by_word_and_char.py
index 620d5af..9acf38c 100644
--- a/test/keystrokes/firefox/flat_review_text_by_word_and_char.py
+++ b/test/keystrokes/firefox/flat_review_text_by_word_and_char.py
@@ -29,7 +29,7 @@ sequence.append(WaitForFocus("Blockquote Regression Test",
 sequence.append(PauseAction(3000))
 
 ########################################################################
 # Read the current word with KP_5.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_5", 1000))
@@ -39,6 +39,14 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'On weaponry: $l', cursor=1",
      "SPEECH OUTPUT: 'On'"]))
 
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("KP_6", 1000))
+sequence.append(utils.AssertPresentationAction(
+    "flat review current word", 
+    ["BRAILLE LINE:  'On weaponry: $l'",
+     "     VISIBLE:  'On weaponry: $l', cursor=4",
+     "SPEECH OUTPUT: 'weaponry:'"]))
+
 ########################################################################
 # Spell the current word with KP_5 2x.
 #
@@ -48,10 +56,10 @@ sequence.append(KeyComboAction("KP_5"))
 sequence.append(utils.AssertPresentationAction(
     "spell current word", 
     ["BRAILLE LINE:  'On weaponry: $l'",
-     "     VISIBLE:  'On weaponry: $l', cursor=12",
+     "     VISIBLE:  'On weaponry: $l', cursor=4",
      "BRAILLE LINE:  'On weaponry: $l'",
-     "     VISIBLE:  'On weaponry: $l', cursor=12",
-     "SPEECH OUTPUT: 'Weaponry:'",
+     "     VISIBLE:  'On weaponry: $l', cursor=4",
+     "SPEECH OUTPUT: 'weaponry:'",
      "SPEECH OUTPUT: 'w'",
      "SPEECH OUTPUT: 'e'",
      "SPEECH OUTPUT: 'a'",
@@ -72,12 +80,12 @@ sequence.append(KeyComboAction("KP_5"))
 sequence.append(utils.AssertPresentationAction(
     "spell current word phonetically", 
     ["BRAILLE LINE:  'On weaponry: $l'",
-     "     VISIBLE:  'On weaponry: $l', cursor=12",
+     "     VISIBLE:  'On weaponry: $l', cursor=4",
      "BRAILLE LINE:  'On weaponry: $l'",
-     "     VISIBLE:  'On weaponry: $l', cursor=12",
+     "     VISIBLE:  'On weaponry: $l', cursor=4",
      "BRAILLE LINE:  'On weaponry: $l'",
-     "     VISIBLE:  'On weaponry: $l', cursor=12",
-     "SPEECH OUTPUT: 'Weaponry:'",
+     "     VISIBLE:  'On weaponry: $l', cursor=4",
+     "SPEECH OUTPUT: 'weaponry:'",
      "SPEECH OUTPUT: 'w'",
      "SPEECH OUTPUT: 'e'",
      "SPEECH OUTPUT: 'a'",
@@ -86,13 +94,16 @@ sequence.append(utils.AssertPresentationAction(
      "SPEECH OUTPUT: 'n'",
      "SPEECH OUTPUT: 'r'",
      "SPEECH OUTPUT: 'y'",
+     "SPEECH OUTPUT: ':'",
      "SPEECH OUTPUT: 'whiskey'",
      "SPEECH OUTPUT: 'echo'",
      "SPEECH OUTPUT: 'alpha'",
      "SPEECH OUTPUT: 'papa'",
      "SPEECH OUTPUT: 'oscar'",
      "SPEECH OUTPUT: 'november'",
-     "SPEECH OUTPUT: 'yankee'"]))
+     "SPEECH OUTPUT: 'romeo'",
+     "SPEECH OUTPUT: 'yankee'",
+     "SPEECH OUTPUT: ':'"]))
 
 ########################################################################
 # Read forward word by word with KP_6.
@@ -29,7 +29,7 @@ sequence.append(WaitForFocus("Blockquote Regression Test",
 
 ########################################################################
-# Read the current word with KP_5.
+# Read the current word with KP_5 and the next word with KP_6.
 #
 sequence.append(utils.StartRecordingAction())
diff --git a/test/keystrokes/firefox/uiuc_radiobutton.py b/test/keystrokes/firefox/uiuc_radiobutton.py
index 1660b7f..6244374 100644
--- a/test/keystrokes/firefox/uiuc_radiobutton.py
+++ b/test/keystrokes/firefox/uiuc_radiobutton.py
@@ -19,23 +19,27 @@ sequence.append(WaitForWindowActivate(utils.firefoxFrameNames, None))
 #
 sequence.append(KeyComboAction("<Control>l"))
 sequence.append(WaitForFocus(acc_role=pyatspi.ROLE_ENTRY))
-sequence.append(TypeAction("http://test.cita.uiuc.edu/aria/radio/view_inline.php?title=Radio%20Example%201&ginc=includes/radio1_inline.inc&gcss=css/radio1_inline.css&gjs=../js/globals.js,../js/widgets_inline.js,js/radio1_inline.js";))
+sequence.append(TypeAction("http://test.cita.illinois.edu/aria/radio/radio1.php";))
 sequence.append(KeyComboAction("Return"))
 sequence.append(WaitForDocLoad())
-sequence.append(WaitForFocus("inline: Radio Example 1", acc_role=pyatspi.ROLE_DOCUMENT_FRAME))
+sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_DOCUMENT_FRAME))
 
 sequence.append(PauseAction(5000))
 
 ########################################################################
 # Move to the first radio button.
 #
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to first button", 
-    ["BRAILLE LINE:  '& y Thai RadioButton'",
-     "     VISIBLE:  '& y Thai RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Lunch Options panel Thai not selected radio button'"]))
+    ["BRAILLE LINE:  '&=y Radio Maria RadioButton'",
+     "     VISIBLE:  '&=y Radio Maria RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Lunch Options panel Radio Maria selected radio button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  The following should be
@@ -45,53 +49,65 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("KP_Enter"))
 sequence.append(utils.AssertPresentationAction(
     "basic whereamI", 
-    ["BRAILLE LINE:  '& y Thai RadioButton'",
-     "     VISIBLE:  '& y Thai RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Lunch Options Thai radio button not selected'"]))
+    ["BRAILLE LINE:  '&=y Radio Maria RadioButton'",
+     "     VISIBLE:  '&=y Radio Maria RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Lunch Options Radio Maria radio button selected'"]))
 
 ########################################################################
 # Move to the second radio button.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "move to second radio button", 
-    ["BRAILLE LINE:  '&=y Subway RadioButton'",
-     "     VISIBLE:  '&=y Subway RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Subway selected radio button'"]))
+    "move to next radio button", 
+    ["BRAILLE LINE:  '& y Radio Maria RadioButton'",
+     "     VISIBLE:  '& y Radio Maria RadioButton', cursor=1",
+     "BRAILLE LINE:  '&=y Rainbow Gardens RadioButton'",
+     "     VISIBLE:  '&=y Rainbow Gardens RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'not selected'",
+     "SPEECH OUTPUT: 'Rainbow Gardens selected radio button'"]))
 
 ########################################################################
 # Move to the third radio button.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "move to third radio button", 
-    ["BRAILLE LINE:  '&=y Jimmy Johns RadioButton'",
-     "     VISIBLE:  '&=y Jimmy Johns RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Jimmy Johns selected radio button'"]))
+    "move to next radio button", 
+    ["BRAILLE LINE:  '& y Rainbow Gardens RadioButton'",
+     "     VISIBLE:  '& y Rainbow Gardens RadioButton', cursor=1",
+     "BRAILLE LINE:  '&=y Thai RadioButton'",
+     "     VISIBLE:  '&=y Thai RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'not selected'",
+     "SPEECH OUTPUT: 'Thai selected radio button'"]))
 
 ########################################################################
 # Move to the fourth radio button.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "move to fourth radio button", 
-    ["BRAILLE LINE:  '&=y Radio Maria RadioButton'",
-     "     VISIBLE:  '&=y Radio Maria RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Radio Maria selected radio button'"]))
+    "move to next radio button", 
+    ["BRAILLE LINE:  '& y Thai RadioButton'",
+     "     VISIBLE:  '& y Thai RadioButton', cursor=1",
+     "BRAILLE LINE:  '&=y Subway RadioButton'",
+     "     VISIBLE:  '&=y Subway RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'not selected'",
+     "SPEECH OUTPUT: 'Subway selected radio button'"]))
 
 ########################################################################
 # Move to the fifth radio button.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "move to fifth radio button", 
-    ["BRAILLE LINE:  '&=y Rainbow Gardens RadioButton'",
-     "     VISIBLE:  '&=y Rainbow Gardens RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Rainbow Gardens selected radio button'"]))
+    "move to next radio button", 
+    ["BRAILLE LINE:  '& y Subway RadioButton'",
+     "     VISIBLE:  '& y Subway RadioButton', cursor=1",
+     "BRAILLE LINE:  '&=y Jimmy Johns RadioButton'",
+     "     VISIBLE:  '&=y Jimmy Johns RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'not selected'",
+     "SPEECH OUTPUT: 'Jimmy Johns selected radio button'"]))
 
 ########################################################################
 # Move to the second radio button group (panel).  Contrast to the first group
@@ -101,9 +117,9 @@ sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to second radio group", 
-    ["BRAILLE LINE:  '&=y Coffee RadioButton'",
-     "     VISIBLE:  '&=y Coffee RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Drink Options panel Coffee selected radio button'"]))
+    ["BRAILLE LINE:  '&=y Water RadioButton'",
+     "     VISIBLE:  '&=y Water RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Drink Options panel Water selected radio button'"]))
 
 ########################################################################
 # Move to the second radio button.
@@ -111,10 +127,13 @@ sequence.append(utils.AssertPresentationAction(
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "move to second radio button grp2",
-    ["BRAILLE LINE:  '&=y Cola RadioButton'",
-     "     VISIBLE:  '&=y Cola RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Cola selected radio button'"]))
+    "move to next radio button grp2",
+    ["BRAILLE LINE:  '& y Water RadioButton'",
+     "     VISIBLE:  '& y Water RadioButton', cursor=1",
+     "BRAILLE LINE:  '&=y Tea RadioButton'",
+     "     VISIBLE:  '&=y Tea RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'not selected'",
+     "SPEECH OUTPUT: 'Tea selected radio button'"]))
 
 ########################################################################
 # Move back to the first radio button.
@@ -122,10 +141,13 @@ sequence.append(utils.AssertPresentationAction(
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
-    "move back to first radio button grp2",
-    ["BRAILLE LINE:  '&=y Coffee RadioButton'",
-     "     VISIBLE:  '&=y Coffee RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Coffee selected radio button'"]))
+    "move back to previous radio button grp2",
+    ["BRAILLE LINE:  '& y Tea RadioButton'",
+     "     VISIBLE:  '& y Tea RadioButton', cursor=1",
+     "BRAILLE LINE:  '&=y Water RadioButton'",
+     "     VISIBLE:  '&=y Water RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'not selected'",
+     "SPEECH OUTPUT: 'Water selected radio button'"]))
 
 ########################################################################
 # Close the demo
@@ -45,53 +49,65 @@ sequence.append(utils.StartRecordingAction())
 
 ########################################################################
-# Move to the second radio button.
+# Move to the next radio button.
 #
 sequence.append(utils.StartRecordingAction())
@@ -45,53 +49,65 @@ sequence.append(utils.StartRecordingAction())
 
 ########################################################################
-# Move to the third radio button.
+# Move to the next radio button.
 #
 sequence.append(utils.StartRecordingAction())
@@ -45,53 +49,65 @@ sequence.append(utils.StartRecordingAction())
 
 ########################################################################
-# Move to the fourth radio button.
+# Move to the next radio button.
 #
 sequence.append(utils.StartRecordingAction())
@@ -45,53 +49,65 @@ sequence.append(utils.StartRecordingAction())
 
 ########################################################################
-# Move to the fifth radio button.
+# Move to the next radio button.
 #
 sequence.append(utils.StartRecordingAction())



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]